import Ajv, { ErrorObject, JSONSchemaType, KeywordDefinition, SchemaObject } from 'ajv';
import { AJVMessageFunction, FormField, IState, useFormErrors } from './types';
import Logger from './Logger';
export declare const getErrors: <T extends Record<string, any>>(ajvErrors: ErrorObject[], userDefinedMessages?: Record<string, AJVMessageFunction>, logger?: Logger, schema?: JSONSchemaType<T> | SchemaObject | undefined) => useFormErrors<T>;
export declare const getInitial: <T extends Record<string, any>>(initialState: T, schema: SchemaObject | JSONSchemaType<T>) => IState<T>;
export declare const getValue: (value: unknown) => {};
export declare const addUserDefinedKeywords: (ajv: Ajv, customKeywords: KeywordDefinition[]) => void;
/**
 * Gets the form state with new field values and dynamically updates `isRequired` for dependent fields.
 *
 * @template T - The type representing the form state.
 * @param {IState<T>} prevState - The current state of the form.
 * @param {Partial<FormField<T>>} form - The updated field values to apply.
 * @param {Record<string, string[]>} fieldDependencies - A map of parent fields to their dependent fields.
 * @param {SchemaObject | JSONSchemaType<T>} schema - The schema defining form validation and dependencies (e.g., `if/then`).
 * @returns {IState<T>} - The updated form state with new values and dynamically updated `isRequired` flags.
 */
export declare const getFormState: <T extends Record<string, any>>(prevState: IState<T>, form: Partial<FormField<T>>, fieldDependencies: Record<string, string[]>, schema: SchemaObject | JSONSchemaType<T>) => IState<T>;
